@@ -31,6 +31,7 @@ typedef struct {
 	dnssec_key_t *key;
 
 	dnssec_binary_t precomputed_ds;
+	dnssec_key_digest_t precomputed_digesttype;
 
 	knot_time_t next_event;
 
@@ -153,12 +154,14 @@ knot_time_t knot_get_next_zone_key_event(const zone_keyset_t *keyset);
  *
  * This function caches the results, so caaling again with the same key returns immediately.
  *
- * \param for_key The key to compute DS for.
- * \param out_donotfree Output: the DS record rdata. Do not call dnssec_binry_free() on this ever.
+ * \param for_key         The key to compute DS for.
+ * \param digesttype      DS digest algorithm.
+ * \param out_donotfree   Output: the DS record rdata. Do not call dnssec_binry_free() on this ever.
  *
  * \return Error code, KNOT_EOK if successful.
  */
-int zone_key_calculate_ds(zone_key_t *for_key, dnssec_binary_t *out_donotfree);
+int zone_key_calculate_ds(zone_key_t *for_key, dnssec_key_digest_t digesttype,
+                          dnssec_binary_t *out_donotfree);
 
 /*!
  * \brief Initialize local signing context.
