@@ -1,4 +1,4 @@
-/*  Copyright (C) 2018 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
+/*  Copyright (C) 2019 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -11,7 +11,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <assert.h>
@@ -72,7 +72,7 @@ static const knot_layer_api_t NOTIFY_API = {
 	.consume = notify_consume,
 };
 
-#define NOTIFY_LOG(priority, zone, remote, fmt, ...) \
+#define NOTIFY_OUT_LOG(priority, zone, remote, fmt, ...) \
 	ns_log(priority, zone, LOG_OPERATION_NOTIFY, LOG_DIRECTION_OUT, remote, \
 	       fmt, ## __VA_ARGS__)
 
@@ -87,7 +87,7 @@ static int send_notify(conf_t *conf, zone_t *zone, const knot_rrset_t *soa,
 
 	query_edns_data_init(&data.edns, conf, zone->name, slave->addr.ss_family);
 
-	struct knot_requestor requestor = { 0 };
+	knot_requestor_t requestor;
 	knot_requestor_init(&requestor, &NOTIFY_API, &data, NULL);
 
 	knot_pkt_t *pkt = knot_pkt_new(NULL, KNOT_WIRE_MAX_PKTSIZE, NULL);
@@ -96,9 +96,9 @@ static int send_notify(conf_t *conf, zone_t *zone, const knot_rrset_t *soa,
 		return KNOT_ENOMEM;
 	}
 
-	const struct sockaddr *dst = (struct sockaddr *)&slave->addr;
-	const struct sockaddr *src = (struct sockaddr *)&slave->via;
-	struct knot_request *req = knot_request_make(NULL, dst, src, pkt, &slave->key, 0);
+	const struct sockaddr_storage *dst = &slave->addr;
+	const struct sockaddr_storage *src = &slave->via;
+	knot_request_t *req = knot_request_make(NULL, dst, src, pkt, &slave->key, 0);
 	if (!req) {
 		knot_request_free(req, NULL);
 		knot_requestor_clear(&requestor);
@@ -108,15 +108,15 @@ static int send_notify(conf_t *conf, zone_t *zone, const knot_rrset_t *soa,
 	int ret = knot_requestor_exec(&requestor, req, timeout);
 
 	if (ret == KNOT_EOK && knot_pkt_ext_rcode(req->resp) == 0) {
-		NOTIFY_LOG(LOG_INFO, zone->name, dst,
-			   "serial %u", knot_soa_serial(soa->rrs.rdata));
+		NOTIFY_OUT_LOG(LOG_INFO, zone->name, dst,
+		               "serial %u", knot_soa_serial(soa->rrs.rdata));
 	} else if (knot_pkt_ext_rcode(req->resp) == 0) {
-		NOTIFY_LOG(LOG_WARNING, zone->name, dst,
-		           "failed (%s)", knot_strerror(ret));
+		NOTIFY_OUT_LOG(LOG_WARNING, zone->name, dst,
+		               "failed (%s)", knot_strerror(ret));
 	} else {
-		NOTIFY_LOG(LOG_WARNING, zone->name, dst,
-		           "server responded with error '%s'",
-		           knot_pkt_ext_rcode_name(req->resp));
+		NOTIFY_OUT_LOG(LOG_WARNING, zone->name, dst,
+		               "server responded with error '%s'",
+		               knot_pkt_ext_rcode_name(req->resp));
 	}
 
 	knot_request_free(req, NULL);
@@ -134,7 +134,7 @@ int event_notify(conf_t *conf, zone_t *zone)
 	}
 
 	// NOTIFY content
-	int timeout = conf->cache.srv_tcp_reply_timeout * 1000;
+	int timeout = conf->cache.srv_tcp_remote_io_timeout;
 	knot_rrset_t soa = node_rrset(zone->contents->apex, KNOT_RRTYPE_SOA);
 
 	// send NOTIFY to each remote, use working address
