@@ -180,8 +180,8 @@ static const struct check_function CHECK_FUNCTIONS[] = {
 	{ check_cname,          MANDATORY },
 	{ check_dname,          MANDATORY },
 	{ check_delegation,     MANDATORY }, // mandatory for apex, optional for others
-	{ check_submission,     OPTIONAL },
 	{ check_ds,             OPTIONAL },
+	{ check_submission,     NSEC | NSEC3 },
 	{ check_rrsig,          NSEC | NSEC3 },
 	{ check_rrsig_signed,   NSEC | NSEC3 },
 	{ check_nsec_bitmap,    NSEC | NSEC3 },
@@ -824,7 +824,11 @@ static int check_nsec(const zone_node_t *node, semchecks_data_t *data)
 	 * so checking should only be matter of testing
 	 * the next link in each node.
 	 */
-	const knot_dname_t *next_domain = knot_nsec_next(nsec_rrs->rdata);
+	knot_dname_storage_t next_domain;
+	if (knot_dname_store(next_domain, knot_nsec_next(nsec_rrs->rdata)) == 0) {
+		return KNOT_EINVAL;
+	}
+	knot_dname_to_lower(next_domain);
 
 	data->next_nsec = zone_contents_find_node(data->zone, next_domain);
 	if (data->next_nsec == NULL) {
@@ -1198,7 +1202,7 @@ static void check_dnskey(zone_contents_t *zone, sem_handler_t *handler)
 	}
 }
 
-int sem_checks_process(zone_contents_t *zone, bool optional, sem_handler_t *handler,
+int sem_checks_process(zone_contents_t *zone, semcheck_optional_t optional, sem_handler_t *handler,
                        time_t time)
 {
 	if (zone == NULL || handler == NULL) {
@@ -1213,9 +1217,10 @@ int sem_checks_process(zone_contents_t *zone, bool optional, sem_handler_t *hand
 		.time = time,
 	};
 
-	if (optional) {
+	if (optional != SEMCHECK_MANDATORY_ONLY) {
 		data.level |= OPTIONAL;
-		if (zone->dnssec) {
+		if (optional == SEMCHECK_DNSSEC ||
+		    (optional == SEMCHECK_AUTO_DNSSEC && zone->dnssec)) {
 			knot_rdataset_t *nsec3param = node_rdataset(zone->apex,
 			                                            KNOT_RRTYPE_NSEC3PARAM);
 			if (nsec3param != NULL) {
