@@ -1,4 +1,4 @@
-/*  Copyright (C) 2017 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
+/*  Copyright (C) 2020 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -11,8 +11,9 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
+
 /*!
  * \file
  *
@@ -45,7 +46,7 @@
 /*!
  * \brief Address family numbers.
  *
- * http://www.iana.org/assignments/address-family-numbers/address-family-numbers.xml
+ * https://www.iana.org/assignments/address-family-numbers/address-family-numbers.xml
  */
 typedef enum {
 	KNOT_ADDR_FAMILY_IPV4 = 1, /*!< IP version 4. */
@@ -55,7 +56,7 @@ typedef enum {
 /*!
  * \brief DNS operation codes (OPCODEs).
  *
- * http://www.iana.org/assignments/dns-parameters/dns-parameters.xml
+ * https://www.iana.org/assignments/dns-parameters/dns-parameters.xml
  */
 typedef enum {
 	KNOT_OPCODE_QUERY  = 0, /*!< Standard query. */
@@ -68,7 +69,7 @@ typedef enum {
 /*!
  * \brief DNS reply codes (RCODEs).
  *
- * http://www.iana.org/assignments/dns-parameters/dns-parameters.xml
+ * https://www.iana.org/assignments/dns-parameters/dns-parameters.xml
  */
 typedef enum {
 	KNOT_RCODE_NOERROR   =  0, /*!< No error. */
@@ -116,7 +117,7 @@ enum knot_ds_algorithm_len
 /*!
  * \brief Constants for DNSSEC algorithm types.
  *
- * Source: http://www.iana.org/assignments/ds-rr-types/ds-rr-types.xml
+ * Source: https://www.iana.org/assignments/ds-rr-types/ds-rr-types.xml
  */
 typedef enum {
 	KNOT_DS_ALG_SHA1   = 1,
@@ -128,9 +129,10 @@ typedef enum {
 /*!
  * \brief DNSSEC algorithm numbers.
  *
- * http://www.iana.org/assignments/dns-sec-alg-numbers/dns-sec-alg-numbers.xml
+ * https://www.iana.org/assignments/dns-sec-alg-numbers/dns-sec-alg-numbers.xml
  */
 typedef enum {
+	KNOT_DNSSEC_ALG_DELETE             =   0,
 	KNOT_DNSSEC_ALG_RSAMD5             =   1,
 	KNOT_DNSSEC_ALG_DH                 =   2,
 	KNOT_DNSSEC_ALG_DSA                =   3,
