@@ -50,6 +50,8 @@
 #include "libknot/packet/pkt.h"
 #include "libknot/packet/rrset-wire.h"
 #include "libknot/packet/wire.h"
+#include "libknot/probe/data.h"
+#include "libknot/probe/probe.h"
 #include "libknot/rrtype/dnskey.h"
 #include "libknot/rrtype/ds.h"
 #include "libknot/rrtype/naptr.h"
