@@ -1,5 +1,5 @@
 
-/*  Copyright (C) 2018 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
+/*  Copyright (C) 2019 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -12,8 +12,8 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ */
 
 #include <string.h>
 
@@ -30,129 +30,134 @@ static const char _yparser_actions[] = {
 	3, 1, 4, 1, 6, 1, 8, 1,
 	9, 1, 10, 1, 11, 1, 12, 1,
 	15, 2, 1, 0, 2, 1, 2, 2,
-	2, 0, 2, 3, 4, 2, 5, 4,
-	2, 6, 0, 2, 7, 8, 2, 12,
-	13, 2, 14, 12, 3, 1, 2, 0,
-	3, 1, 7, 8, 3, 1, 12, 13,
-	3, 1, 14, 12, 3, 2, 7, 8,
-	3, 2, 12, 13, 3, 2, 14, 12,
-	4, 1, 2, 7, 8, 4, 1, 2,
-	12, 13, 4, 1, 2, 14, 12
+	1, 15, 2, 2, 0, 2, 3, 4,
+	2, 5, 4, 2, 6, 0, 2, 7,
+	8, 2, 12, 13, 2, 14, 12, 3,
+	1, 2, 0, 3, 1, 7, 8, 3,
+	1, 12, 13, 3, 1, 14, 12, 3,
+	2, 7, 8, 3, 2, 12, 13, 3,
+	2, 14, 12, 4, 1, 2, 7, 8,
+	4, 1, 2, 12, 13, 4, 1, 2,
+	14, 12
 };
 
 static const unsigned char _yparser_key_offsets[] = {
-	0, 0, 13, 15, 16, 25, 36, 38,
-	39, 49, 60, 71, 73, 76, 89, 93,
-	96, 100, 102, 105, 115, 124, 127, 130,
-	133, 137, 140, 143, 146, 157, 170, 183,
-	196
+	0, 0, 15, 17, 29, 31, 34, 46,
+	47, 58, 70, 72, 73, 83, 94, 98,
+	100, 103, 107, 110, 113, 126, 136, 145,
+	148, 151, 154, 158, 161, 164, 179, 194,
+	209
 };
 
 static const char _yparser_trans_keys[] = {
-	10, 13, 32, 35, 45, 46, 92, 48,
-	57, 65, 90, 97, 122, 10, 13, 32,
-	32, 46, 92, 48, 57, 65, 90, 97,
-	122, 32, 58, 92, 45, 46, 48, 57,
-	65, 90, 97, 122, 32, 58, 32, 32,
-	33, 34, 92, 36, 43, 45, 90, 94,
-	126, 10, 13, 32, 33, 92, 36, 43,
-	45, 90, 94, 126, 32, 58, 92, 45,
-	46, 48, 57, 65, 90, 97, 122, 32,
-	58, 10, 13, 32, 10, 13, 32, 34,
-	35, 91, 92, 33, 43, 45, 90, 94,
-	126, 34, 92, 32, 126, 10, 13, 32,
-	10, 13, 32, 35, 10, 13, 34, 32,
-	126, 32, 33, 34, 92, 36, 43, 45,
-	90, 94, 126, 32, 33, 44, 92, 93,
-	36, 90, 94, 126, 32, 44, 93, 10,
-	13, 32, 34, 32, 126, 34, 92, 32,
-	126, 32, 44, 93, 34, 32, 126, 34,
-	32, 126, 32, 58, 92, 45, 46, 48,
-	57, 65, 90, 97, 122, 10, 13, 32,
-	35, 45, 46, 92, 48, 57, 65, 90,
-	97, 122, 10, 13, 32, 35, 45, 46,
-	92, 48, 57, 65, 90, 97, 122, 10,
-	13, 32, 35, 45, 46, 92, 48, 57,
-	65, 90, 97, 122, 10, 13, 32, 35,
-	45, 46, 92, 48, 57, 65, 90, 97,
-	122, 0
+	10, 13, 32, 35, 42, 45, 46, 92,
+	95, 48, 57, 65, 90, 97, 122, 10,
+	13, 32, 58, 92, 95, 45, 46, 48,
+	57, 65, 90, 97, 122, 32, 58, 10,
+	13, 32, 32, 58, 92, 95, 45, 46,
+	48, 57, 65, 90, 97, 122, 32, 32,
+	42, 46, 92, 95, 48, 57, 65, 90,
+	97, 122, 32, 58, 92, 95, 45, 46,
+	48, 57, 65, 90, 97, 122, 32, 58,
+	32, 32, 33, 34, 92, 36, 43, 45,
+	90, 94, 126, 10, 13, 32, 33, 92,
+	36, 43, 45, 90, 94, 126, 10, 13,
+	32, 35, 10, 13, 34, 32, 126, 34,
+	92, 32, 126, 10, 13, 32, 34, 32,
+	126, 10, 13, 32, 34, 35, 91, 92,
+	33, 43, 45, 90, 94, 126, 32, 33,
+	34, 92, 36, 43, 45, 90, 94, 126,
+	32, 33, 44, 92, 93, 36, 90, 94,
+	126, 32, 44, 93, 10, 13, 32, 34,
+	32, 126, 34, 92, 32, 126, 32, 44,
+	93, 34, 32, 126, 10, 13, 32, 35,
+	42, 45, 46, 92, 95, 48, 57, 65,
+	90, 97, 122, 10, 13, 32, 35, 42,
+	45, 46, 92, 95, 48, 57, 65, 90,
+	97, 122, 10, 13, 32, 35, 42, 45,
+	46, 92, 95, 48, 57, 65, 90, 97,
+	122, 10, 13, 32, 35, 42, 45, 46,
+	92, 95, 48, 57, 65, 90, 97, 122,
+	0
 };
 
 static const char _yparser_single_lengths[] = {
-	0, 7, 2, 1, 3, 3, 2, 1,
-	4, 5, 3, 2, 3, 7, 2, 3,
-	4, 2, 1, 4, 5, 3, 3, 1,
-	2, 3, 1, 1, 3, 7, 7, 7,
-	7
+	0, 9, 2, 4, 2, 3, 4, 1,
+	5, 4, 2, 1, 4, 5, 4, 2,
+	1, 2, 3, 1, 7, 4, 5, 3,
+	3, 1, 2, 3, 1, 9, 9, 9,
+	9
 };
 
 static const char _yparser_range_lengths[] = {
-	0, 3, 0, 0, 3, 4, 0, 0,
-	3, 3, 4, 0, 0, 3, 1, 0,
-	0, 0, 1, 3, 2, 0, 0, 1,
-	1, 0, 1, 1, 4, 3, 3, 3,
+	0, 3, 0, 4, 0, 0, 4, 0,
+	3, 4, 0, 0, 3, 3, 0, 0,
+	1, 1, 0, 1, 3, 3, 2, 0,
+	0, 1, 1, 0, 1, 3, 3, 3,
 	3
 };
 
 static const unsigned char _yparser_index_offsets[] = {
-	0, 0, 11, 14, 16, 23, 31, 34,
-	36, 44, 53, 61, 64, 68, 79, 83,
-	87, 92, 95, 98, 106, 114, 118, 122,
-	125, 129, 133, 136, 139, 147, 158, 169,
-	180
+	0, 0, 13, 16, 25, 28, 32, 41,
+	43, 52, 61, 64, 66, 74, 83, 88,
+	91, 94, 98, 102, 105, 116, 124, 132,
+	136, 140, 143, 147, 151, 154, 167, 180,
+	193
 };
 
 static const char _yparser_indicies[] = {
-	1, 2, 3, 4, 5, 6, 6, 6,
-	6, 6, 0, 1, 2, 4, 7, 0,
-	7, 8, 8, 8, 8, 8, 0, 9,
-	11, 10, 10, 10, 10, 10, 0, 12,
-	13, 0, 14, 0, 14, 15, 16, 17,
-	15, 15, 15, 0, 18, 19, 20, 21,
-	22, 21, 21, 21, 0, 23, 25, 24,
-	24, 24, 24, 24, 0, 26, 27, 0,
-	28, 29, 30, 0, 28, 29, 30, 16,
-	31, 32, 17, 15, 15, 15, 0, 34,
-	35, 33, 0, 18, 19, 20, 0, 28,
-	29, 36, 31, 0, 28, 29, 31, 37,
-	33, 0, 32, 38, 39, 40, 38, 38,
-	38, 0, 41, 42, 43, 44, 45, 42,
-	42, 0, 46, 32, 47, 0, 28, 29,
-	36, 0, 48, 42, 0, 50, 51, 49,
-	0, 41, 43, 45, 0, 52, 49, 0,
-	53, 21, 0, 54, 56, 55, 55, 55,
-	55, 55, 0, 1, 2, 3, 4, 5,
-	57, 57, 57, 57, 57, 0, 58, 59,
-	60, 61, 62, 63, 63, 63, 63, 63,
-	0, 64, 65, 66, 67, 68, 69, 69,
-	69, 69, 69, 0, 70, 71, 72, 73,
-	74, 75, 75, 75, 75, 75, 0, 0
+	1, 2, 3, 4, 5, 6, 5, 5,
+	5, 5, 5, 5, 0, 1, 2, 4,
+	7, 9, 8, 8, 8, 8, 8, 8,
+	0, 10, 11, 0, 12, 13, 14, 0,
+	15, 17, 16, 16, 16, 16, 16, 16,
+	0, 18, 0, 18, 19, 19, 19, 19,
+	19, 19, 19, 0, 20, 22, 21, 21,
+	21, 21, 21, 21, 0, 23, 24, 0,
+	25, 0, 25, 26, 27, 28, 26, 26,
+	26, 0, 29, 30, 31, 32, 33, 32,
+	32, 32, 0, 12, 13, 34, 35, 0,
+	12, 13, 35, 36, 32, 0, 38, 39,
+	37, 0, 29, 30, 31, 0, 40, 37,
+	0, 12, 13, 14, 27, 35, 41, 28,
+	26, 26, 26, 0, 41, 42, 43, 44,
+	42, 42, 42, 0, 45, 46, 47, 48,
+	49, 46, 46, 0, 50, 41, 51, 0,
+	12, 13, 34, 0, 52, 46, 0, 54,
+	55, 53, 0, 45, 47, 49, 0, 56,
+	53, 0, 1, 2, 3, 4, 57, 6,
+	57, 57, 57, 57, 57, 57, 0, 59,
+	60, 61, 62, 63, 64, 63, 63, 63,
+	63, 63, 63, 58, 65, 66, 67, 68,
+	69, 70, 69, 69, 69, 69, 69, 69,
+	0, 71, 72, 73, 74, 75, 76, 75,
+	75, 75, 75, 75, 75, 58, 0
 };
 
 static const char _yparser_trans_targs[] = {
-	0, 30, 31, 1, 2, 3, 28, 4,
-	5, 6, 5, 7, 6, 7, 8, 9,
-	14, 27, 32, 29, 16, 9, 27, 11,
-	10, 12, 11, 12, 32, 29, 13, 17,
-	19, 14, 15, 18, 16, 14, 20, 24,
-	23, 21, 20, 19, 23, 22, 21, 22,
-	20, 24, 25, 26, 24, 9, 11, 28,
-	12, 10, 30, 31, 1, 2, 3, 10,
-	30, 31, 1, 2, 3, 10, 30, 31,
-	1, 2, 3, 10
+	0, 30, 31, 1, 2, 3, 7, 4,
+	3, 5, 4, 5, 32, 29, 20, 4,
+	6, 5, 8, 9, 10, 9, 11, 10,
+	11, 12, 13, 17, 16, 32, 29, 14,
+	13, 16, 14, 15, 13, 17, 18, 19,
+	17, 21, 22, 26, 25, 23, 22, 21,
+	25, 24, 23, 24, 22, 26, 27, 28,
+	26, 6, 0, 30, 31, 1, 2, 6,
+	7, 30, 31, 1, 2, 6, 7, 30,
+	31, 1, 2, 6, 7
 };
 
 static const char _yparser_trans_actions[] = {
-	23, 1, 0, 46, 0, 49, 43, 21,
-	43, 19, 13, 19, 0, 0, 0, 34,
-	7, 34, 40, 11, 11, 9, 9, 15,
-	13, 15, 0, 0, 1, 0, 0, 0,
-	0, 9, 0, 9, 0, 37, 34, 7,
-	34, 11, 9, 11, 9, 11, 0, 0,
-	37, 9, 0, 9, 37, 37, 17, 13,
-	17, 43, 52, 28, 85, 28, 90, 80,
-	31, 5, 72, 5, 76, 68, 25, 3,
-	60, 3, 64, 56
+	23, 1, 0, 49, 0, 46, 52, 17,
+	13, 17, 0, 0, 1, 0, 0, 15,
+	13, 15, 21, 46, 19, 13, 19, 0,
+	0, 0, 37, 7, 37, 43, 11, 11,
+	9, 9, 0, 0, 40, 9, 0, 9,
+	40, 0, 37, 7, 37, 11, 9, 11,
+	9, 11, 0, 0, 40, 9, 0, 9,
+	40, 46, 31, 55, 28, 88, 28, 83,
+	93, 34, 5, 75, 5, 71, 79, 25,
+	3, 63, 3, 59, 67
 };
 
 static const char _yparser_eof_actions[] = {
