@@ -124,6 +124,7 @@ static bool genkeyargs(int argc, char *argv[], bool just_timing,
 	algnames[DNSSEC_KEY_ALGORITHM_ECDSA_P256_SHA256] = "ecdsap256sha256";
 	algnames[DNSSEC_KEY_ALGORITHM_ECDSA_P384_SHA384] = "ecdsap384sha384";
 	algnames[DNSSEC_KEY_ALGORITHM_ED25519] = "ed25519";
+	algnames[DNSSEC_KEY_ALGORITHM_ED448] = "ed448";
 
 	// parse args
 	for (int i = 0; i < argc; i++) {
@@ -215,12 +216,13 @@ int keymgr_generate_key(kdnssec_ctx_t *ctx, int argc, char *argv[])
 		gen_timing.ready = gen_timing.active;
 	}
 
-	if (keysize > 0) {
-		if ((flags & DNSKEY_GENERATE_KSK)) {
-			ctx->policy->ksk_size = keysize;
-		} else {
-			ctx->policy->zsk_size = keysize;
-		}
+	if (keysize == 0) {
+		keysize = dnssec_algorithm_key_size_default(ctx->policy->algorithm);
+	}
+	if ((flags & DNSKEY_GENERATE_KSK)) {
+		ctx->policy->ksk_size = keysize;
+	} else {
+		ctx->policy->zsk_size = keysize;
 	}
 
 	for (size_t i = 0; i < ctx->zone->num_keys; i++) {
@@ -623,11 +625,11 @@ int keymgr_nsec3_salt_set(kdnssec_ctx_t *ctx, const char *new_salt)
 	return ret;
 }
 
-int keymgr_serial_print(kdnssec_ctx_t *ctx)
+int keymgr_serial_print(kdnssec_ctx_t *ctx, kaspdb_serial_t type)
 {
 	uint32_t serial = 0;
 	int ret = kasp_db_load_serial(ctx->kasp_db, ctx->zone->dname,
-	                              KASPDB_SERIAL_LASTSIGNED, &serial);
+	                              type, &serial);
 	switch (ret) {
 	case KNOT_EOK:
 		printf("Current serial: %u\n", serial);
@@ -640,10 +642,10 @@ int keymgr_serial_print(kdnssec_ctx_t *ctx)
 	return ret;
 }
 
-int keymgr_serial_set(kdnssec_ctx_t *ctx, uint32_t new_serial)
+int keymgr_serial_set(kdnssec_ctx_t *ctx, kaspdb_serial_t type, uint32_t new_serial)
 {
 	return kasp_db_store_serial(ctx->kasp_db, ctx->zone->dname,
-	                            KASPDB_SERIAL_LASTSIGNED, new_serial);
+	                            type, new_serial);
 }
 
 static void print_tsig(dnssec_tsig_algorithm_t mac, const char *name,
